@@ -86,6 +86,9 @@ INVALIDPARAMETER_DISKCONFIGNOTSUPPORTED = 'InvalidParameter.DiskConfigNotSupport
 # 云硬盘大小与快照大小不匹配。
 INVALIDPARAMETER_DISKSIZENOTMATCH = 'InvalidParameter.DiskSizeNotMatch'
 
+# ClientToken不可用。
+INVALIDPARAMETER_INVALIDCLIENTTOKEN = 'InvalidParameter.InvalidClientToken'
+
 # 项目ID不存在。
 INVALIDPARAMETER_PROJECTIDNOTEXIST = 'InvalidParameter.ProjectIdNotExist'
 
@@ -113,6 +116,9 @@ LIMITEXCEEDED_AUTOSNAPSHOTPOLICYOUTOFQUOTA = 'LimitExceeded.AutoSnapshotPolicyOu
 # 实例挂载云盘数量超过限制。
 LIMITEXCEEDED_INSTANCEATTACHEDDISK = 'LimitExceeded.InstanceAttachedDisk'
 
+# 调用标签服务超过了频率限制。
+LIMITEXCEEDED_TAGQUOTALIMITEXCEEDED = 'LimitExceeded.TagQuotaLimitExceeded'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -152,6 +158,9 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # 云硬盘已挂载至其他云服务器上。
 RESOURCEUNAVAILABLE_ATTACHED = 'ResourceUnavailable.Attached'
 
+# 数据备份点尚未创建完成，暂时不可使用。
+RESOURCEUNAVAILABLE_DISKBACKUPCREATING = 'ResourceUnavailable.DiskBackupCreating'
+
 # 云硬盘快照链长度过长，拒绝创建快照。
 RESOURCEUNAVAILABLE_DISKSNAPSHOTCHAINTOOLARGE = 'ResourceUnavailable.DiskSnapshotChainTooLarge'
 
@@ -188,6 +197,9 @@ TRADEDEALCONFLICT = 'TradeDealConflict'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# CAM鉴权Token不可用。
+UNAUTHORIZEDOPERATION_INVALIDTOKEN = 'UnauthorizedOperation.InvalidToken'
+
 # MFA鉴权过期，请重试。
 UNAUTHORIZEDOPERATION_MFAEXPIRED = 'UnauthorizedOperation.MFAExpired'
 
@@ -215,6 +227,9 @@ UNSUPPORTEDOPERATION_INSTANCENOTSTOPPED = 'UnsupportedOperation.InstanceNotStopp
 # 该快照已经共享，请先解除共享。
 UNSUPPORTEDOPERATION_SNAPHASSHARED = 'UnsupportedOperation.SnapHasShared'
 
+# 快照组关联快照的原云硬盘未挂载在同一实例上。
+UNSUPPORTEDOPERATION_SNAPSHOTGROUPDISKATTACHMULTIINSTANCE = 'UnsupportedOperation.SnapshotGroupDiskAttachMultiInstance'
+
 # 该快照创建了自定义快照，请先删除对应镜像。
 UNSUPPORTEDOPERATION_SNAPSHOTHASBINDEDIMAGE = 'UnsupportedOperation.SnapshotHasBindedImage'
 
