@@ -26,6 +26,29 @@ class CccClient(AbstractClient):
     _service = 'ccc'
 
 
+    def AbortAgentCruiseDialingCampaign(self, request):
+        """停止座席巡航式外呼任务
+
+        :param request: Request instance for AbortAgentCruiseDialingCampaign.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.AbortAgentCruiseDialingCampaignRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.AbortAgentCruiseDialingCampaignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AbortAgentCruiseDialingCampaign", params, headers=headers)
+            response = json.loads(body)
+            model = models.AbortAgentCruiseDialingCampaignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AbortPredictiveDialingCampaign(self, request):
         """停止预测式外呼任务
 
@@ -49,6 +72,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def BindNumberCallInInterface(self, request):
+        """绑定号码呼入回调接口
+
+        :param request: Request instance for BindNumberCallInInterface.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallInInterfaceRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallInInterfaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BindNumberCallInInterface", params, headers=headers)
+            response = json.loads(body)
+            model = models.BindNumberCallInInterfaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BindNumberCallOutSkillGroup(self, request):
         """绑定号码外呼技能组
 
@@ -168,6 +214,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAgentCruiseDialingCampaign(self, request):
+        """座席巡航式外呼。
+
+        :param request: Request instance for CreateAgentCruiseDialingCampaign.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAgentCruiseDialingCampaignRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAgentCruiseDialingCampaignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAgentCruiseDialingCampaign", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAgentCruiseDialingCampaignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAutoCalloutTask(self, request):
         """创建自动外呼任务
 
@@ -448,6 +517,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteCCCSkillGroup(self, request):
+        """删除技能组
+
+        :param request: Request instance for DeleteCCCSkillGroup.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DeleteCCCSkillGroupRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DeleteCCCSkillGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCCCSkillGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCCCSkillGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteExtension(self, request):
         """删除话机账号
 
@@ -540,6 +632,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAILatency(self, request):
+        """获取 AI 时延信息
+
+        :param request: Request instance for DescribeAILatency.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAILatencyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAILatencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAILatency", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAILatencyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeActiveCarrierPrivilegeNumber(self, request):
         """查询生效运营商白名单规则
 
@@ -563,6 +678,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAgentCruiseDialingCampaign(self, request):
+        """查询 座席巡航式外呼任务
+
+        :param request: Request instance for DescribeAgentCruiseDialingCampaign.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAgentCruiseDialingCampaignRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAgentCruiseDialingCampaignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAgentCruiseDialingCampaign", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAgentCruiseDialingCampaignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAutoCalloutTask(self, request):
         """查询自动外呼任务详情
 
@@ -1163,6 +1301,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ForceMemberOffline(self, request):
+        """强制客服下线
+
+        :param request: Request instance for ForceMemberOffline.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ForceMemberOfflineRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ForceMemberOfflineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ForceMemberOffline", params, headers=headers)
+            response = json.loads(body)
+            model = models.ForceMemberOfflineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def HangUpCall(self, request):
         """挂断电话
 
@@ -1347,6 +1508,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestoreMemberOnline(self, request):
+        """恢复客服上线
+
+        :param request: Request instance for RestoreMemberOnline.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.RestoreMemberOnlineRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.RestoreMemberOnlineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestoreMemberOnline", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestoreMemberOnlineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResumePredictiveDialingCampaign(self, request):
         """恢复预测式外呼任务
 
@@ -1393,6 +1577,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def TransferToManual(self, request):
+        """特定场景下讲会话转接到人工坐席
+
+        :param request: Request instance for TransferToManual.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.TransferToManualRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.TransferToManualResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("TransferToManual", params, headers=headers)
+            response = json.loads(body)
+            model = models.TransferToManualResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UnbindNumberCallOutSkillGroup(self, request):
         """解绑号码外呼技能组
 
