@@ -189,7 +189,6 @@ class CfsClient(AbstractClient):
 
     def CreateMigrationTask(self, request):
         """用于创建迁移任务。
-        此接口需提交工单，开启白名单之后才能使用。
 
         :param request: Request instance for CreateMigrationTask.
         :type request: :class:`tencentcloud.cfs.v20190719.models.CreateMigrationTaskRequest`
@@ -327,8 +326,7 @@ class CfsClient(AbstractClient):
 
 
     def DeleteMigrationTask(self, request):
-        """用于删除迁移任务。
-        此接口需提交工单，开启白名单之后才能使用。
+        """用于删除迁移任务。不支持删除等待中、创建中、运行中、取消中、终止中状态的任务。
 
         :param request: Request instance for DeleteMigrationTask.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteMigrationTaskRequest`
@@ -445,7 +443,6 @@ class CfsClient(AbstractClient):
 
     def DescribeBucketList(self, request):
         """用于获取数据源桶列表。
-        此接口需提交工单，开启白名单之后才能使用。
 
         :param request: Request instance for DescribeBucketList.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeBucketListRequest`
@@ -814,8 +811,7 @@ class CfsClient(AbstractClient):
 
 
     def StopMigrationTask(self, request):
-        """用于终止迁移任务，非运行中状态不支持终止。
-        此接口需提交工单，开启白名单之后才能使用。
+        """用于终止迁移任务，可以终止等待中、运行中状态的任务。
 
         :param request: Request instance for StopMigrationTask.
         :type request: :class:`tencentcloud.cfs.v20190719.models.StopMigrationTaskRequest`
