@@ -28,8 +28,10 @@ import logging.handlers
 
 try:
     from urllib.parse import urlencode
+    from urllib.parse import urlparse
 except ImportError:
     from urllib import urlencode
+    from urlparse import urlparse
 
 import tencentcloud
 from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
@@ -133,11 +135,11 @@ class AbstractClient(object):
         elif self.profile.signMethod == "TC3-HMAC-SHA256" or options.get("IsMultipart") is True:
             self._build_req_with_tc3_signature(action, params, req_inter, options)
         elif self.profile.signMethod in ("HmacSHA1", "HmacSHA256"):
-            self._build_req_with_old_signature(action, params, req_inter)
+            self._build_req_with_old_signature(action, params, req_inter, options)
         else:
             raise TencentCloudSDKException("ClientError", "Invalid signature method.")
 
-    def _build_req_with_old_signature(self, action, params, req):
+    def _build_req_with_old_signature(self, action, params, req, options):
         params = copy.deepcopy(self._fix_params(params))
         params['Action'] = action[0].upper() + action[1:]
         params['RequestClient'] = self.request_client
@@ -160,7 +162,7 @@ class AbstractClient(object):
         if self.profile.language:
             params['Language'] = self.profile.language
 
-        signInParam = self._format_sign_string(params)
+        signInParam = self._format_sign_string(params, options)
         params['Signature'] = Sign.sign(str(self.credential.secret_key),
                                         str(signInParam),
                                         str(self.profile.signMethod))
@@ -185,7 +187,7 @@ class AbstractClient(object):
             raise SDKError("ClientError",
                            "Invalid request method GET for multipart.")
 
-        endpoint = self._get_endpoint()
+        endpoint = self._get_endpoint(options=options)
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
@@ -276,7 +278,7 @@ class AbstractClient(object):
             raise SDKError("ClientError",
                            "Invalid request method GET for multipart.")
 
-        endpoint = self._get_endpoint()
+        endpoint = self._get_endpoint(options=options)
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
@@ -333,20 +335,23 @@ class AbstractClient(object):
             logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp_inter))
             raise TencentCloudSDKException("ServerNetworkError", resp_inter.content)
 
-    def _format_sign_string(self, params):
+    def _format_sign_string(self, params, options=None):
         formatParam = {}
         for k in params:
             formatParam[k.replace('_', '.')] = params[k]
         strParam = '&'.join('%s=%s' % (k, formatParam[k]) for k in sorted(formatParam))
-        msg = '%s%s%s?%s' % (self.profile.httpProfile.reqMethod, self._get_endpoint(), self._requestPath, strParam)
+        msg = '%s%s%s?%s' % (
+            self.profile.httpProfile.reqMethod, self._get_endpoint(options=options), self._requestPath, strParam)
         return msg
 
     def _get_service_domain(self):
         rootDomain = self.profile.httpProfile.rootDomain
         return self._service + "." + rootDomain
 
-    def _get_endpoint(self):
+    def _get_endpoint(self, options=None):
         endpoint = self.profile.httpProfile.endpoint
+        if not endpoint and options:
+            endpoint = urlparse(options.get("Endpoint", "")).hostname
         if endpoint is None:
             endpoint = self._get_service_domain()
         return endpoint
@@ -420,7 +425,7 @@ class AbstractClient(object):
             headers["X-TC-TraceId"] = str(uuid.uuid4())
         if not self.profile.disable_region_breaker:
             return self._call_with_region_breaker(action, params, options, headers)
-        req = RequestInternal(self._get_endpoint(),
+        req = RequestInternal(self._get_endpoint(options=options),
                               self.profile.httpProfile.reqMethod,
                               self._requestPath,
                               header=headers)
@@ -444,7 +449,7 @@ class AbstractClient(object):
         return retryer.send_request(_call_once).content
 
     def _call_with_region_breaker(self, action, params, options=None, headers=None):
-        endpoint = self._get_endpoint()
+        endpoint = self._get_endpoint(options=options)
         generation, need_break = self.circuit_breaker.before_requests()
         if need_break:
             endpoint = self._service + "." + self.profile.region_breaker_profile.backup_endpoint
@@ -470,33 +475,34 @@ class AbstractClient(object):
         self._check_error(resp)
         return resp.content
 
-    def call_octet_stream(self, action, headers, body):
-        """
-        Invoke API with application/ocet-stream content-type.
+    def call_octet_stream(self, action, headers, body, options=None):
+        """Invoke API with application/ocet-stream content-type.
 
         Note:
         1. only specific API can be invoked in such manner.
         2. only TC3-HMAC-SHA256 signature method can be specified.
         3. only POST request method can be specified
 
-        :type action: str
         :param action: Specific API action name.
-        :type headers: dict
+        :type action: str
         :param headers: Header parameters for this API.
-        :type body: bytes
+        :type headers: dict
         :param body: Bytes of requested body
+        :type body: bytes
         """
         if self.profile.signMethod != "TC3-HMAC-SHA256":
             raise SDKError("ClientError", "Invalid signature method.")
         if self.profile.httpProfile.reqMethod != "POST":
             raise SDKError("ClientError", "Invalid request method.")
 
-        req = RequestInternal(self._get_endpoint(),
+        if not options:
+            options = {}
+        req = RequestInternal(self._get_endpoint(options=options),
                               self.profile.httpProfile.reqMethod,
                               self._requestPath,
                               header=headers)
         req.data = body
-        options = {"IsOctetStream": True}
+        options["IsOctetStream"] = True
         self._build_req_inter(action, None, req, options)
 
         resp = self.request.send_request(req)
@@ -505,17 +511,16 @@ class AbstractClient(object):
         return json.loads(resp.content)
 
     def call_json(self, action, params, headers=None, options=None):
-        """
-        Call api with json object and return with json object.
+        """Call api with json object and return with json object.
 
-        :type action: str
         :param action: api name e.g. ``DescribeInstances``
+        :type action: str
+        :param params: Request parameters of this action
         :type params: dict
-        :param params: params with this action
+        :param headers: Request headers, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
         :type headers: dict
-        :param headers: request header, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
+        :param options: Request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
         :type options: dict
-        :param options: request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
         """
 
         def _call_once():
@@ -529,6 +534,18 @@ class AbstractClient(object):
         return json.loads(retryer.send_request(_call_once).content)
 
     def call_sse(self, action, params, headers=None, options=None):
+        """Call api with json object and return with sse event.
+
+        :param action: api name e.g. ``ChatCompletions``
+        :type action: str
+        :param params: Request parameters of this action
+        :type params: dict
+        :param headers: Request headers, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
+        :type headers: dict
+        :param options: Request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
+        :type options: dict
+        """
+
         def _call_once():
             resp = self._call(action, params, options, headers)
             self._check_status(resp)
@@ -557,15 +574,14 @@ class AbstractClient(object):
         return self._process_response_json(resp, resp_type)
 
     def set_stream_logger(self, stream=None, level=logging.DEBUG, log_format=None):
-        """
-        Add a stream handler
+        """Add a stream handler
 
-        :type stream: IO[str]
         :param stream: e.g. ``sys.stdout`` ``sys.stdin`` ``sys.stderr``
-        :type level: int
+        :type stream: IO[str]
         :param level: Logging level, e.g. ``logging.INFO``
-        :type log_format: str
+        :type level: int
         :param log_format: Log message format
+        :type log_format: str
         """
         log = logging.getLogger(LOGGER_NAME)
         log.setLevel(level)
@@ -578,15 +594,14 @@ class AbstractClient(object):
         log.addHandler(sh)
 
     def set_file_logger(self, file_path, level=logging.DEBUG, log_format=None):
-        """
-        Add a file handler
+        """Add a file handler
 
-        :type file_path: str
         :param file_path: path of log file
-        :type level: int
+        :type file_path: str
         :param level: Logging level, e.g. ``logging.INFO``
-        :type log_format: str
+        :type level: int
         :param log_format: Log message format
+        :type log_format: str
         """
         log = logging.getLogger(LOGGER_NAME)
         log.setLevel(level)
@@ -600,9 +615,7 @@ class AbstractClient(object):
         log.addHandler(fh)
 
     def set_default_logger(self):
-        """
-        Set default log handler
-        """
+        """Set default log handler"""
         log = logging.getLogger(LOGGER_NAME)
         log.handlers = []
         logger.addHandler(EmptyHandler())
