@@ -95,6 +95,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CancelOnlineDDLJob(self, request):
+        """取消 Online DDL 任务
+
+        :param request: Request instance for CancelOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.CancelOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.CancelOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CancelOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.CancelOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CloneAccount(self, request):
         """本接口（CloneAccount）用于克隆实例账户。
 
@@ -257,6 +280,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOnlineDDLJob(self, request):
+        """创建在线DDL任务
+
+        :param request: Request instance for CreateOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.CreateOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.CreateOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateTmpDCDBInstance(self, request):
         """回档TDSQL实例
 
@@ -350,6 +396,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBackupConfigs(self, request):
+        """本接口(DescribeBackupConfigs)用于查询数据库备份配置信息。
+
+        :param request: Request instance for DescribeBackupConfigs.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeBackupConfigsRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeBackupConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackupConfigs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackupConfigsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBackupFiles(self, request):
         """本接口(DescribeBackupFiles)用于查看备份文件列表。
 
@@ -903,6 +972,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeOnlineDDLJob(self, request):
+        """查询Online DDL 任务详情
+
+        :param request: Request instance for DescribeOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeOrders(self, request):
         """本接口（DescribeOrders）用于查询分布式数据库订单信息。传入订单ID来查询订单关联的分布式数据库实例，和对应的任务流程ID。
 
@@ -1324,6 +1416,31 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyBackupConfigs(self, request):
+        """本接口(ModifyBackupConfigs)用于修改数据库备份配置信息。
+
+        1. 修改数据库超期备份配置，目前按年、按月、按日只支持一种，存在互斥关系，如当前策略按年备份，如果传入按月备份策略将会覆盖当前的按年备份策略，务必注意。
+
+        :param request: Request instance for ModifyBackupConfigs.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.ModifyBackupConfigsRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.ModifyBackupConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyBackupConfigs", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyBackupConfigsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDBEncryptAttributes(self, request):
         """本接口(ModifyDBEncryptAttributes)用于修改实例数据加密。
 
