@@ -71,6 +71,9 @@ FAILEDOPERATION_DOMAINOWNEDBYOTHERUSER = 'FailedOperation.DomainOwnedByOtherUser
 # 校验公网 IP 发生异常。
 FAILEDOPERATION_EIPCHECKFAILED = 'FailedOperation.EipCheckFailed'
 
+# 文件不存在或文件还未生成
+FAILEDOPERATION_FILENOTEXIST = 'FailedOperation.FileNotExist'
+
 # 您操作过于频繁，请稍后重试
 FAILEDOPERATION_FREQUENCYLIMIT = 'FailedOperation.FrequencyLimit'
 
@@ -143,6 +146,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 您的账号已被系统封禁，如果您有任何疑问请与我们联系。
 INVALIDPARAMETER_ACCOUNTISBANNED = 'InvalidParameter.AccountIsBanned'
 
+# 域名正在取回，请勿重复操作。
+INVALIDPARAMETER_ACQUIREHASHEXISTS = 'InvalidParameter.AcquireHashExists'
+
 # 无效的操作。
 INVALIDPARAMETER_ACTIONINVALID = 'InvalidParameter.ActionInvalid'
 
@@ -158,6 +164,9 @@ INVALIDPARAMETER_ALIASISMYDOMAIN = 'InvalidParameter.AliasIsMyDomain'
 # 创建批量域名任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHDOMAINCREATEACTIONERROR = 'InvalidParameter.BatchDomainCreateActionError'
 
+# 您有批量任务未执行完成，请等待完成后继续添加。
+INVALIDPARAMETER_BATCHLIMITUNDO = 'InvalidParameter.BatchLimitUndo'
+
 # 创建批量记录任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHRECORDCREATEACTIONERROR = 'InvalidParameter.BatchRecordCreateActionError'
 
@@ -458,6 +467,12 @@ INVALIDPARAMETER_PARAMSMISSING = 'InvalidParameter.ParamsMissing'
 # 鉴权失败。
 INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'
 
+# 无效的 IP 地址。
+INVALIDPARAMETER_PTRINVALIDPUBLICIP = 'InvalidParameter.PtrInvalidPublicIp'
+
+# 你不是该 IP 的所有者，无法进行此操作。
+INVALIDPARAMETER_PTRIPNOTOWNER = 'InvalidParameter.PtrIpNotOwner'
+
 # 用户UIN无效。
 INVALIDPARAMETER_QCLOUDUININVALID = 'InvalidParameter.QcloudUinInvalid'
 
@@ -500,9 +515,15 @@ INVALIDPARAMETER_REQUESTIPLIMITED = 'InvalidParameter.RequestIpLimited'
 # 搜索结果大于500条，请增加关键字。
 INVALIDPARAMETER_RESULTMORETHAN500 = 'InvalidParameter.ResultMoreThan500'
 
+# 已经存在此共享记录。
+INVALIDPARAMETER_SHAREUSEREXISTS = 'InvalidParameter.ShareUserExists'
+
 # 共享用户中包含未实名认证用户。
 INVALIDPARAMETER_SHAREDUSERSUNREALNAME = 'InvalidParameter.SharedUsersUnrealName'
 
+# 开始时间不能大于结束时间。
+INVALIDPARAMETER_STARTTIMEGREATERTHANENDTIME = 'InvalidParameter.StarttimeGreaterThanEndtime'
+
 # 状态代码不正确。
 INVALIDPARAMETER_STATUSCODEINVALID = 'InvalidParameter.StatusCodeInvalid'
 
@@ -524,6 +545,12 @@ INVALIDPARAMETER_TOOMANYINVALIDDOMAINS = 'InvalidParameter.TooManyInvalidDomains
 # 域名无效。
 INVALIDPARAMETER_TOOLSDOMAININVALID = 'InvalidParameter.ToolsDomainInvalid'
 
+# 域名未注册。
+INVALIDPARAMETER_TOOLSDOMAINNOTREGED = 'InvalidParameter.ToolsDomainNotReged'
+
+# 您要过户到的账号已被系统封禁，如果您有任何疑问请与我们联系。
+INVALIDPARAMETER_TRANSFERACCOUNTISBANNED = 'InvalidParameter.TransferAccountIsBanned'
+
 # 解锁代码已失效。
 INVALIDPARAMETER_UNLOCKCODEEXPIRED = 'InvalidParameter.UnLockCodeExpired'
 
