@@ -46,7 +46,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CheckTransformation(self, request):
@@ -69,7 +69,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateConnection(self, request):
@@ -92,7 +92,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateEventBus(self, request):
@@ -115,7 +115,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateRule(self, request):
@@ -138,7 +138,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTarget(self, request):
@@ -161,7 +161,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTransformation(self, request):
@@ -184,7 +184,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteConnection(self, request):
@@ -207,7 +207,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteEventBus(self, request):
@@ -230,7 +230,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteRule(self, request):
@@ -253,7 +253,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTarget(self, request):
@@ -276,7 +276,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTransformation(self, request):
@@ -299,11 +299,11 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLogTagValue(self, request):
-        """查询日志索引维度值
+        """前置条件：需开启事件存储；事件查询维度值
 
         :param request: Request instance for DescribeLogTagValue.
         :type request: :class:`tencentcloud.eb.v20210416.models.DescribeLogTagValueRequest`
@@ -322,7 +322,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetEventBus(self, request):
@@ -345,7 +345,30 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def GetPlatformEventTemplate(self, request):
+        """获取平台产品事件模板
+
+        :param request: Request instance for GetPlatformEventTemplate.
+        :type request: :class:`tencentcloud.eb.v20210416.models.GetPlatformEventTemplateRequest`
+        :rtype: :class:`tencentcloud.eb.v20210416.models.GetPlatformEventTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetPlatformEventTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetPlatformEventTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetRule(self, request):
@@ -368,7 +391,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetTransformation(self, request):
@@ -391,7 +414,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListConnections(self, request):
@@ -414,7 +437,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListEventBuses(self, request):
@@ -437,7 +460,76 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ListPlatformEventNames(self, request):
+        """获取平台产品事件名称
+
+        :param request: Request instance for ListPlatformEventNames.
+        :type request: :class:`tencentcloud.eb.v20210416.models.ListPlatformEventNamesRequest`
+        :rtype: :class:`tencentcloud.eb.v20210416.models.ListPlatformEventNamesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListPlatformEventNames", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListPlatformEventNamesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ListPlatformEventPatterns(self, request):
+        """获取平台产品事件匹配规则
+
+        :param request: Request instance for ListPlatformEventPatterns.
+        :type request: :class:`tencentcloud.eb.v20210416.models.ListPlatformEventPatternsRequest`
+        :rtype: :class:`tencentcloud.eb.v20210416.models.ListPlatformEventPatternsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListPlatformEventPatterns", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListPlatformEventPatternsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ListPlatformProducts(self, request):
+        """获取平台产品列表
+
+        :param request: Request instance for ListPlatformProducts.
+        :type request: :class:`tencentcloud.eb.v20210416.models.ListPlatformProductsRequest`
+        :rtype: :class:`tencentcloud.eb.v20210416.models.ListPlatformProductsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListPlatformProducts", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListPlatformProductsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListRules(self, request):
@@ -460,7 +552,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTargets(self, request):
@@ -483,7 +575,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PublishEvent(self, request):
@@ -506,7 +598,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PutEvents(self, request):
@@ -529,11 +621,11 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SearchLog(self, request):
-        """日志检索
+        """前置条件：开启事件存储；查询历史推送事件
 
         :param request: Request instance for SearchLog.
         :type request: :class:`tencentcloud.eb.v20210416.models.SearchLogRequest`
@@ -552,7 +644,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateConnection(self, request):
@@ -575,7 +667,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateEventBus(self, request):
@@ -598,7 +690,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateRule(self, request):
@@ -621,7 +713,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateTarget(self, request):
@@ -644,7 +736,7 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateTransformation(self, request):
@@ -667,4 +759,4 @@ class EbClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
