@@ -27,7 +27,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeDomains(self, request):
-        """本接口（DescribeDomains）用于查询CDN域名基本信息，包括项目id，状态，业务类型，创建时间，更新时间等。
+        """ECDN平台下线，接口开始预下线处理
+
+        本接口（DescribeDomains）用于查询CDN域名基本信息，包括项目id，状态，业务类型，创建时间，更新时间等。
 
         >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41118"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
 
@@ -52,7 +54,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeDomainsConfig(self, request):
-        """本接口（DescribeDomainsConfig）用于查询CDN加速域名详细配置信息。
+        """ECDN平台下线，接口开始预下线处理
+
+        本接口（DescribeDomainsConfig）用于查询CDN加速域名详细配置信息。
 
         >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41117"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
 
@@ -77,7 +81,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeEcdnDomainLogs(self, request):
-        """本接口（DescribeEcdnDomainLogs）用于查询域名的访问日志下载地址。
+        """ECDN平台下线，接口开始预下线处理
+
+        本接口（DescribeEcdnDomainLogs）用于查询域名的访问日志下载地址。
 
         :param request: Request instance for DescribeEcdnDomainLogs.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeEcdnDomainLogsRequest`
@@ -100,7 +106,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeEcdnDomainStatistics(self, request):
-        """本接口（DescribeEcdnDomainStatistics）用于查询指定时间段内的域名访问统计指标。
+        """ECDN平台下线，接口开始预下线处理
+
+        本接口（DescribeEcdnDomainStatistics）用于查询指定时间段内的域名访问统计指标。
 
         >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/30986"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
 
@@ -125,7 +133,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeEcdnStatistics(self, request):
-        """DescribeEcdnStatistics用于查询 ECDN 实时访问监控数据，支持以下指标查询：
+        """ECDN平台下线，接口开始预下线处理
+
+        DescribeEcdnStatistics用于查询 ECDN 实时访问监控数据，支持以下指标查询：
 
         + 流量（单位为 byte）
         + 带宽（单位为 bps）
@@ -156,7 +166,9 @@ class EcdnClient(AbstractClient):
 
 
     def DescribeIpStatus(self, request):
-        """DescribeIpStatus 用于查询域名所在加速平台的所有节点信息, 如果您的源站有白名单设置,可以通过本接口获取ECDN服务的节点IP进行加白, 本接口为内测接口,请联系腾讯云工程师开白。
+        """ECDN平台下线，接口开始预下线处理
+
+        DescribeIpStatus 用于查询域名所在加速平台的所有节点信息, 如果您的源站有白名单设置,可以通过本接口获取ECDN服务的节点IP进行加白, 本接口为内测接口,请联系腾讯云工程师开白。
 
         由于产品服务节点常有更新，对于源站开白的使用场景，请定期调用接口获取最新节点信息，若新增服务节点发布7日后您尚未更新加白导致回源失败等问题，ECDN侧不对此承担责任。
 
