@@ -211,7 +211,7 @@ class FaceidClient(AbstractClient):
 
 
     def DetectAIFakeFaces(self, request):
-        """提供对人脸图片/视频的AI合成、翻拍、水印等攻击痕迹的检测，增强图片/视频防伪能力
+        """基于多模态的AI大模型算法，提供对人脸图片、视频的防攻击检测能力，可针对性有效识别高仿真的AIGC换脸、高清翻拍、批量黑产攻击、水印等攻击痕迹，增强对图片和视频的防伪安全能力。
 
         :param request: Request instance for DetectAIFakeFaces.
         :type request: :class:`tencentcloud.faceid.v20180301.models.DetectAIFakeFacesRequest`
@@ -579,7 +579,7 @@ class FaceidClient(AbstractClient):
 
 
     def ImageRecognition(self, request):
-        """传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人。
+        """传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人（该接口已停止接入，新客户请使用<a href="https://cloud.tencent.com/document/product/1007/102203">照片人脸核身（V2.0）</a>接口）。
 
         :param request: Request instance for ImageRecognition.
         :type request: :class:`tencentcloud.faceid.v20180301.models.ImageRecognitionRequest`
