@@ -211,7 +211,7 @@ class IotvideoClient(AbstractClient):
 
 
     def ChangeP2PRoute(self, request):
-        """p2p路线切换
+        """p2p路线切换（此接口目前处于内测接口，可以联系申请加白 ）
 
         :param request: Request instance for ChangeP2PRoute.
         :type request: :class:`tencentcloud.iotvideo.v20211125.models.ChangeP2PRouteRequest`
@@ -1153,6 +1153,29 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCsReportCountDataInfo(self, request):
+        """获取云存上报统计信息
+
+        :param request: Request instance for DescribeCsReportCountDataInfo.
+        :type request: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCsReportCountDataInfoRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCsReportCountDataInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCsReportCountDataInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCsReportCountDataInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDataForwardList(self, request):
         """获取数据转发列表
 
