@@ -62,6 +62,12 @@ FAILEDOPERATION_INSTANCECANNOTRETURN = 'FailedOperation.InstanceCanNotReturn'
 # 实例退费失败。
 FAILEDOPERATION_INSTANCERETURNFAILED = 'FailedOperation.InstanceReturnFailed'
 
+# 日志不存在。
+FAILEDOPERATION_LOGNOTEXISTED = 'FailedOperation.LogNotExisted'
+
+# 修改备份设置失败
+FAILEDOPERATION_MODIFYBACKUPCONFIGSFAILED = 'FailedOperation.ModifyBackupConfigsFailed'
+
 # 修改账号权限失败。
 FAILEDOPERATION_MODIFYRIGHTFAILED = 'FailedOperation.ModifyRightFailed'
 
@@ -92,6 +98,9 @@ FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
 # 标签配额不足。
 FAILEDOPERATION_TAGQUOTAEXCEEDLIMIT = 'FailedOperation.TagQuotaExceedLimit'
 
+# 计费配置查询失败
+FAILEDOPERATION_TRADECONFIGNOTFOUND = 'FailedOperation.TradeConfigNotFound'
+
 # 实例安全组信息更新失败。
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
@@ -137,6 +146,9 @@ INTERNALERROR_DBOPERATIONFAILED = 'InternalError.DbOperationFailed'
 # 查询独享集群信息失败。
 INTERNALERROR_FENCEERROR = 'InternalError.FenceError'
 
+# 获取数据库加密密钥失败。
+INTERNALERROR_GETCIPHERTEXTFAILED = 'InternalError.GetCipherTextFailed'
+
 # 获取数据库实例参数失败。
 INTERNALERROR_GETDBCONFIGFAILED = 'InternalError.GetDbConfigFailed'
 
@@ -407,6 +419,9 @@ UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 # 没有权限操作该接口或资源。
 UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'
 
+# 不支持该数据库版本。
+UNSUPPORTEDOPERATION_DBVERSIONNOTSUPPORTED = 'UnsupportedOperation.DbVersionNotSupported'
+
 # 不支持的无效操作。
 UNSUPPORTEDOPERATION_INVALIDOPERATION = 'UnsupportedOperation.InvalidOperation'
 
