@@ -245,6 +245,9 @@ INVALIDPARAMETER_CLUSTERNOTFOUND = 'InvalidParameter.ClusterNotFound'
 # 重复提交任务。
 INVALIDPARAMETER_DUPTASK = 'InvalidParameter.DupTask'
 
+# 无效的AppId。
+INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'
+
 # 参数错误。
 INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 
