@@ -35,6 +35,9 @@ FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 # 登录信息验证失败，token 验证失败。
 FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
 
+# 绑定插件失败，请检查参数。
+FAILEDOPERATION_BINDPLUGIN = 'FailedOperation.BindPlugin'
+
 # 调用 NetDeploy 失败。
 FAILEDOPERATION_CALLNETDEPLOYFAILED = 'FailedOperation.CallNetDeployFailed'
 
@@ -44,6 +47,9 @@ FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 # CLS服务未注册。
 FAILEDOPERATION_CLSSERVICEUNREGISTERED = 'FailedOperation.ClsServiceUnregistered'
 
+# 函数集群不存在。
+FAILEDOPERATION_CLUSTERNOTFOUND = 'FailedOperation.ClusterNotFound'
+
 # CopyAsyncRun 传参异常。
 FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
 
@@ -89,6 +95,12 @@ FAILEDOPERATION_DELETENAMESPACE = 'FailedOperation.DeleteNamespace'
 # 删除触发器失败。
 FAILEDOPERATION_DELETETRIGGER = 'FailedOperation.DeleteTrigger'
 
+# Url被占用，无法删除。
+FAILEDOPERATION_DELETETRIGGER_URLUSED = 'FailedOperation.DeleteTrigger.UrlUsed'
+
+# 自定义域名不存在
+FAILEDOPERATION_DOMAIN_UNEXIST = 'FailedOperation.Domain.UnExist'
+
 # 当前函数状态无法更新代码，请在状态为正常时更新。
 FAILEDOPERATION_FUNCTIONNAMESTATUSERROR = 'FailedOperation.FunctionNameStatusError'
 
@@ -161,6 +173,9 @@ FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 # ServiceClosed 请确认后再操作。
 FAILEDOPERATION_SERVICECLOSED = 'FailedOperation.ServiceClosed'
 
+# 更新自定义域名失败，SSL异常。
+FAILEDOPERATION_SSL = 'FailedOperation.Ssl'
+
 # Topic不存在。
 FAILEDOPERATION_TOPICNOTEXIST = 'FailedOperation.TopicNotExist'
 
@@ -182,6 +197,9 @@ FAILEDOPERATION_UPDATEFUNCTIONCONFIGURATION = 'FailedOperation.UpdateFunctionCon
 # 更新状态操作失败。
 FAILEDOPERATION_UPDATESTATUS = 'FailedOperation.UpdateStatus'
 
+# 更新触发器出错。
+FAILEDOPERATION_UPDATETRIGGER = 'FailedOperation.UpdateTrigger'
+
 # 与原状态一致，无需更改。
 FAILEDOPERATION_UPDATETRIGGERSTATUS = 'FailedOperation.UpdateTriggerStatus'
 
@@ -221,9 +239,12 @@ INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 # 日志参数有误。
 INVALIDPARAMETER_CLS = 'InvalidParameter.Cls'
 
-# FunctionName取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# FunctionName取值与规范不符，请修正后再试。
 INVALIDPARAMETER_FUNCTIONNAME = 'InvalidParameter.FunctionName'
 
+# 资源ID和函数名参数不能同时为空。
+INVALIDPARAMETER_FUNCTIONNAMEORRESOURCEIDREQUIRED = 'InvalidParameter.FunctionNameOrResourceIdRequired'
+
 # 创建函数传参异常。
 INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 
@@ -242,7 +263,7 @@ INVALIDPARAMETER_ROUTINGCONFIG = 'InvalidParameter.RoutingConfig'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# Action取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# Action取值与规范不符，请修正后再试。可参考：https://cloud.tencent.com/document/product/583/17235。
 INVALIDPARAMETERVALUE_ACTION = 'InvalidParameterValue.Action'
 
 # AdditionalVersionWeights参数传入错误。
@@ -266,6 +287,9 @@ INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
 # Args 参数值有误。
 INVALIDPARAMETERVALUE_ARGS = 'InvalidParameterValue.Args'
 
+# 容器启动参数取值与规范不符。
+INVALIDPARAMETERVALUE_ARGSLIST = 'InvalidParameterValue.ArgsList'
+
 # AsyncRunEnable 取值不正确。
 INVALIDPARAMETERVALUE_ASYNCRUNENABLE = 'InvalidParameterValue.AsyncRunEnable'
 
@@ -275,6 +299,9 @@ INVALIDPARAMETERVALUE_ASYNCTRIGGERCONFIG = 'InvalidParameterValue.AsyncTriggerCo
 # Cdn传入错误。
 INVALIDPARAMETERVALUE_CDN = 'InvalidParameterValue.Cdn'
 
+# CertConfig配置为空。
+INVALIDPARAMETERVALUE_CERTCONFIG_EMPTY = 'InvalidParameterValue.CertConfig.empty'
+
 # cfs配置项重复。
 INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParameterDuplicate'
 
@@ -311,19 +338,25 @@ INVALIDPARAMETERVALUE_CODESOURCE = 'InvalidParameterValue.CodeSource'
 # Command[Entrypoint] 参数值有误。
 INVALIDPARAMETERVALUE_COMMAND = 'InvalidParameterValue.Command'
 
+# 容器启动命令参数值与规范不符。
+INVALIDPARAMETERVALUE_COMMANDLIST = 'InvalidParameterValue.CommandList'
+
 # CompatibleRuntimes参数传入错误。
 INVALIDPARAMETERVALUE_COMPATIBLERUNTIMES = 'InvalidParameterValue.CompatibleRuntimes'
 
 # Content参数传入错误。
 INVALIDPARAMETERVALUE_CONTENT = 'InvalidParameterValue.Content'
 
+# Cors 字段传值异常。
+INVALIDPARAMETERVALUE_CORS = 'InvalidParameterValue.Cors'
+
 # Cos传入错误。
 INVALIDPARAMETERVALUE_COS = 'InvalidParameterValue.Cos'
 
 # CosBucketName不符合规范。
 INVALIDPARAMETERVALUE_COSBUCKETNAME = 'InvalidParameterValue.CosBucketName'
 
-# CosBucketRegion取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# CosBucketRegion取值与规范不符，请修正后再试。可参考：https://cloud.tencent.com/document/product/583/17244#Code。
 INVALIDPARAMETERVALUE_COSBUCKETREGION = 'InvalidParameterValue.CosBucketRegion'
 
 # COS通知规则冲突。
@@ -338,7 +371,7 @@ INVALIDPARAMETERVALUE_CUSTOMARGUMENT = 'InvalidParameterValue.CustomArgument'
 # DateTime传入错误。
 INVALIDPARAMETERVALUE_DATETIME = 'InvalidParameterValue.DateTime'
 
-# DeadLetterConfig取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# DeadLetterConfig取值与规范不符，请修正后再试。可参考：https://cloud.tencent.com/document/product/583/17244#DeadLetterConfig。
 INVALIDPARAMETERVALUE_DEADLETTERCONFIG = 'InvalidParameterValue.DeadLetterConfig'
 
 # 默认Namespace无法创建。
@@ -353,16 +386,22 @@ INVALIDPARAMETERVALUE_DEMOID = 'InvalidParameterValue.DemoId'
 # Description传入错误。
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
+# DiskSize 参数取值不规范。
+INVALIDPARAMETERVALUE_DISKSIZE = 'InvalidParameterValue.DiskSize'
+
 # 环境变量DNS[OS_NAMESERVER]配置有误。
 INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
 
 # DynamicEnabled 参数传入错误。
 INVALIDPARAMETERVALUE_DYNAMICENABLED = 'InvalidParameterValue.DynamicEnabled'
 
+# EASConfig参数异常。
+INVALIDPARAMETERVALUE_EASCONFIG = 'InvalidParameterValue.EASConfig'
+
 # EipConfig参数错误。
 INVALIDPARAMETERVALUE_EIPCONFIG = 'InvalidParameterValue.EipConfig'
 
-# Enable取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# Enable取值与规范不符，请修正后再试。
 INVALIDPARAMETERVALUE_ENABLE = 'InvalidParameterValue.Enable'
 
 # Environment传入错误。
@@ -377,9 +416,6 @@ INVALIDPARAMETERVALUE_ENVIRONMENTSYSTEMPROTECT = 'InvalidParameterValue.Environm
 # Filters参数错误。
 INVALIDPARAMETERVALUE_FILTERS = 'InvalidParameterValue.Filters'
 
-# Function取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
-INVALIDPARAMETERVALUE_FUNCTION = 'InvalidParameterValue.Function'
-
 # 函数不存在。
 INVALIDPARAMETERVALUE_FUNCTIONNAME = 'InvalidParameterValue.FunctionName'
 
@@ -392,7 +428,7 @@ INVALIDPARAMETERVALUE_FUNCTIONTYPE = 'InvalidParameterValue.FunctionType'
 # GitBranch不符合规范。
 INVALIDPARAMETERVALUE_GITBRANCH = 'InvalidParameterValue.GitBranch'
 
-# GitCommitId取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# GitCommitId取值与规范不符，请修正后再试。
 INVALIDPARAMETERVALUE_GITCOMMITID = 'InvalidParameterValue.GitCommitId'
 
 # GitDirectory不符合规范。
@@ -455,7 +491,7 @@ INVALIDPARAMETERVALUE_LOGFORMAT = 'InvalidParameterValue.LogFormat'
 # MaxConcurrency 参数传入错误。
 INVALIDPARAMETERVALUE_MAXCONCURRENCY = 'InvalidParameterValue.MaxConcurrency'
 
-# Memory取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# Memory 取值与规范不符，函数运行时内存大小默认为128MB，可选范围64MB、128MB - 3072MB，以128MB为阶梯，请修正后重试。
 INVALIDPARAMETERVALUE_MEMORY = 'InvalidParameterValue.Memory'
 
 # MemorySize错误。
@@ -485,7 +521,7 @@ INVALIDPARAMETERVALUE_OFFSET = 'InvalidParameterValue.Offset'
 # Order传入错误。
 INVALIDPARAMETERVALUE_ORDER = 'InvalidParameterValue.Order'
 
-# OrderBy取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# OrderBy取值与规范不符，请修正后再试。可参考对应接口文档中的示例值：https://cloud.tencent.com/document/product/583/17235
 INVALIDPARAMETERVALUE_ORDERBY = 'InvalidParameterValue.OrderBy'
 
 # 入参不是标准的json。
@@ -521,7 +557,7 @@ INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
 # RetCode不合法。
 INVALIDPARAMETERVALUE_RETCODE = 'InvalidParameterValue.RetCode'
 
-# RoutingConfig取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+# RoutingConfig取值与规范不符，请修正后再试。可参考：https://cloud.tencent.com/document/product/583/17244#RoutingConfig。
 INVALIDPARAMETERVALUE_ROUTINGCONFIG = 'InvalidParameterValue.RoutingConfig'
 
 # Runtime传入错误。
@@ -653,6 +689,9 @@ LIMITEXCEEDED_NAMESPACE = 'LimitExceeded.Namespace'
 # Offset超出限制。
 LIMITEXCEEDED_OFFSET = 'LimitExceeded.Offset'
 
+# 特权容器属性开启失败
+LIMITEXCEEDED_PRIVILEGECONTAINER = 'LimitExceeded.PrivilegeContainer'
+
 # 定时预置数量超过最大限制。
 LIMITEXCEEDED_PROVISIONTRIGGERACTION = 'LimitExceeded.ProvisionTriggerAction'
 
@@ -875,9 +914,15 @@ UNSUPPORTEDOPERATION_ASYNCRUNENABLE = 'UnsupportedOperation.AsyncRunEnable'
 # Cdn不支持。
 UNSUPPORTEDOPERATION_CDN = 'UnsupportedOperation.Cdn'
 
+# 该函数无法复制。
+UNSUPPORTEDOPERATION_COPYFUNCTION = 'UnsupportedOperation.CopyFunction'
+
 # Cos操作不支持。
 UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 
+# DiskSize 配置内测中，需要申请开启。如需使用可联系我们。
+UNSUPPORTEDOPERATION_DISKSIZE = 'UnsupportedOperation.DiskSize'
+
 # 指定的配置EipFixed暂不支持。
 UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
 
