@@ -27,9 +27,9 @@ class TatClient(AbstractClient):
 
 
     def CancelInvocation(self, request):
-        """取消一台或多台CVM实例执行的命令
+        """取消一台或多台实例执行的命令
 
-        * 如果命令还未下发到agent，任务状态处于处于PENDING、DELIVERING、DELIVER_DELAYED，取消后任务状态是CANCELLED
+        * 如果命令还未下发到agent，任务状态处于PENDING、DELIVERING、DELIVER_DELAYED，取消后任务状态是CANCELLED
         * 如果命令已下发到agent，任务状态处于RUNNING， 取消后任务状态是TERMINATED
 
         :param request: Request instance for CancelInvocation.
@@ -145,6 +145,29 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteCommands(self, request):
+        """批量删除命令接口
+
+        :param request: Request instance for DeleteCommands.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DeleteCommandsRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DeleteCommandsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCommands", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCommandsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteInvoker(self, request):
         """此接口用于删除执行器。
 
@@ -352,6 +375,29 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeQuotas(self, request):
+        """此接口用于获取配额信息
+
+        :param request: Request instance for DescribeQuotas.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DescribeQuotasRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DescribeQuotasResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeQuotas", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeQuotasResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRegions(self, request):
         """此接口用于查询 TAT 产品后台地域列表。
         RegionState 为 AVAILABLE，代表该地域的 TAT 后台服务已经可用；未返回，代表该地域的 TAT 后台服务尚不可用。
@@ -422,6 +468,29 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeScenes(self, request):
+        """此接口用于查询场景详情。
+
+        :param request: Request instance for DescribeScenes.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DescribeScenesRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DescribeScenesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeScenes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeScenesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DisableInvoker(self, request):
         """此接口用于停止执行器。
 
