@@ -35,21 +35,33 @@ FAILEDOPERATION_CONFIGCONDITIONUNKNOWNTARGET = 'FailedOperation.ConfigConditionU
 # 配置文件Condition表达式值的项不能为空。
 FAILEDOPERATION_CONFIGCONDITIONVALUEEMPTYERROR = 'FailedOperation.ConfigConditionValueEmptyError'
 
+# 配置文件不允许重复的关键字。
+FAILEDOPERATION_CONFIGDUPLICATEKEYERROR = 'FailedOperation.ConfigDuplicateKeyError'
+
 # 配置文件存在类型不匹配的字段。
 FAILEDOPERATION_CONFIGFIELDTYPEERROR = 'FailedOperation.ConfigFieldTypeError'
 
 # 配置文件存在语法错误。
 FAILEDOPERATION_CONFIGFORMATERROR = 'FailedOperation.ConfigFormatError'
 
+# 版本管理配置文件JSON格式错误
+FAILEDOPERATION_CONFIGJSONFORMATERROR = 'FailedOperation.ConfigJSONFormatError'
+
 # 配置文件内容格式错误，无法解析。
 FAILEDOPERATION_CONFIGMALFORMEDCONTENT = 'FailedOperation.ConfigMalformedContent'
 
 # 配置文件参数校验错误。
 FAILEDOPERATION_CONFIGPARAMVALIDATEERRORS = 'FailedOperation.ConfigParamValidateErrors'
 
+# 时间格式解析错误
+FAILEDOPERATION_CONFIGTIMEPARSINGERROR = 'FailedOperation.ConfigTimeParsingError'
+
 # 配置文件无法识别的字段：存在拼写错误，或者该字段所在的层级出错。
 FAILEDOPERATION_CONFIGUNKNOWNFIELD = 'FailedOperation.ConfigUnknownField'
 
+# 不支持的配置项Action
+FAILEDOPERATION_CONFIGUNSUPPORTEDACTION = 'FailedOperation.ConfigUnsupportedAction'
+
 # 当前不支持该配置文件版本。
 FAILEDOPERATION_CONFIGUNSUPPORTEDFORMATVERSION = 'FailedOperation.ConfigUnsupportedFormatVersion'
 
@@ -389,6 +401,9 @@ INVALIDPARAMETER_INVALIDCONDITIONS = 'InvalidParameter.InvalidConditions'
 # 无效的回源配置，源站类型为对象存储时，源站地址必须为对象存储域名。
 INVALIDPARAMETER_INVALIDCOSDOMAIN = 'InvalidParameter.InvalidCosDomain'
 
+# 域名非法，请检查入参中是否传入不存在的域名。
+INVALIDPARAMETER_INVALIDDOMAINS = 'InvalidParameter.InvalidDomains'
+
 # 无效的智能加速。
 INVALIDPARAMETER_INVALIDDYNAMICROUTINE = 'InvalidParameter.InvalidDynamicRoutine'
 
@@ -482,6 +497,9 @@ INVALIDPARAMETER_INVALIDPRIVATEACCESSPARAMS = 'InvalidParameter.InvalidPrivateAc
 # 请指定PrivateAccess参数值为on/off。
 INVALIDPARAMETER_INVALIDPRIVATEACCESSSWITCH = 'InvalidParameter.InvalidPrivateAccessSwitch'
 
+# 四层代理非法，请检查入参中是否传入不存在的代理。
+INVALIDPARAMETER_INVALIDPROXIES = 'InvalidParameter.InvalidProxies'
+
 # 套餐包不支持Quic配置。
 INVALIDPARAMETER_INVALIDQUICBILLING = 'InvalidParameter.InvalidQuicBilling'
 
@@ -581,6 +599,9 @@ INVALIDPARAMETER_LOADBALANCERBINDL4NOTINSTABLESTATUS = 'InvalidParameter.LoadBal
 # 引用负载均衡的7层域名服务正在部署中，请稍后再编辑。
 INVALIDPARAMETER_LOADBALANCERBINDL7NOTINSTABLESTATUS = 'InvalidParameter.LoadBalancerBindL7NotInStableStatus'
 
+# 负载均衡器绑定的源站组无效。
+INVALIDPARAMETER_LOADBALANCERBINDORIGINGROUPINVALID = 'InvalidParameter.LoadBalancerBindOriginGroupInvalid'
+
 # 同一站点下的负载均衡名称不可以重复。
 INVALIDPARAMETER_LOADBALANCERNAMEREPEATED = 'InvalidParameter.LoadBalancerNameRepeated'
 
@@ -1046,6 +1067,9 @@ OPERATIONDENIED_L4STATUSNOTINONLINE = 'OperationDenied.L4StatusNotInOnline'
 # 存在加速域名处于部署中状态，暂不支持停用站点。
 OPERATIONDENIED_L7HOSTINPROCESSSTATUS = 'OperationDenied.L7HostInProcessStatus'
 
+# 回源白名单已经是最新版本，无需更新。
+OPERATIONDENIED_LATESTVERSIONNOW = 'OperationDenied.LatestVersionNow'
+
 # 绑定负载均衡有处于非运行中的状态，禁止操作。
 OPERATIONDENIED_LOADBALANCESTATUSNOTINONLINE = 'OperationDenied.LoadBalanceStatusNotInOnline'
 
@@ -1133,6 +1157,12 @@ OPERATIONDENIED_STATICIPAREACONFLICT = 'OperationDenied.StaticIpAreaConflict'
 # 当前并不支持关闭回源双向认证，如需关闭，请通过将边缘 HTTPS 证书更改为不配置来关闭。
 OPERATIONDENIED_UNSUPPORTTOCLOSEUPSTREAMMTLS = 'OperationDenied.UnSupportToCloseUpstreamMTLS'
 
+# 套餐不支持。
+OPERATIONDENIED_UNSUPPORTEDPLAN = 'OperationDenied.UnsupportedPlan'
+
+# 请先更新IP白名单。
+OPERATIONDENIED_UPDATEIPWHITELISTFIRST = 'OperationDenied.UpdateIPWhitelistFirst'
+
 # 如需启用回源双向认证，请先配置边缘 HTTPS 证书。
 OPERATIONDENIED_USEUPSTREAMMTLSNEEDOPENHTTPS = 'OperationDenied.UseUpstreamMTLSNeedOpenHttps'
 
