@@ -17,12 +17,24 @@
 # API元数据解析失败。
 FAILEDOPERATION_APIMETAPARSEFAILED = 'FailedOperation.ApiMetaParseFailed'
 
+# 调用TSF-APM服务获取配置列表失败
+FAILEDOPERATION_APMGETCONFIGSFAILED = 'FailedOperation.ApmGetConfigsFailed'
+
 # 创建应用，获取ES鉴权信息失败。
 FAILEDOPERATION_APPLICATIONCREATEESATUHERROR = 'FailedOperation.ApplicationCreateEsAtuhError'
 
 # 应用查询失败。
 FAILEDOPERATION_APPLICATIONQUERYFAILED = 'FailedOperation.ApplicationQueryFailed'
 
+# TSF应用性能管理调用tsf-dcfg模块失败
+FAILEDOPERATION_CALLTSFDCFGFAILED = 'FailedOperation.CallTsfDcfgFailed'
+
+# 调用CDI状态接口失败
+FAILEDOPERATION_CDISTATUSFAILED = 'FailedOperation.CdiStatusFailed'
+
+# 调用CDI状态返回数据异常
+FAILEDOPERATION_CDISTATUSINVALID = 'FailedOperation.CdiStatusInvalid'
+
 # TSF云API请求调用失败。
 FAILEDOPERATION_CLOUDAPIPROXYERROR = 'FailedOperation.CloudApiProxyError'
 
@@ -86,9 +98,24 @@ FAILEDOPERATION_CONTAINERGROUPKUBERNETESAPIINVOKEERROR = 'FailedOperation.Contai
 # 调用 kube-api-server 失败。
 FAILEDOPERATION_CONTAINERGROUPKUBERNETESCONNECTERROR = 'FailedOperation.ContainergroupKubernetesConnectError'
 
+# k8s集群可能处于异常状态，请删除或恢复k8s集群后，再进行操作
+FAILEDOPERATION_CONTAINERGROUPKUBERNETESTKECLUSTERABNORMAL = 'FailedOperation.ContainergroupKubernetesTkeClusterAbnormal'
+
+# 容器平台集群不可用，当前状态 %s
+FAILEDOPERATION_CPCLUSTERUNAVAILABLE = 'FailedOperation.CpClusterUnavailable'
+
 # 健康检查配置失败。
 FAILEDOPERATION_CVMCAEMASTERHEALTHCHECKCONFIGERROR = 'FailedOperation.CvmCaeMasterHealthCheckConfigError'
 
+# TSF暂时不能响应请求。
+FAILEDOPERATION_DISPATCHCOMMONERROR = 'FailedOperation.DispatchCommonError'
+
+# 寻找独占配置中心相关指标异常
+FAILEDOPERATION_FINDMETRICSEXCLUSIVEERROR = 'FailedOperation.FindMetricsExclusiveError'
+
+# 网关通用异常:%s。
+FAILEDOPERATION_GATEWAYCOMMONERROR = 'FailedOperation.GatewayCommonError'
+
 # 远端访问错误: %s。
 FAILEDOPERATION_GATEWAYREMOTECALLERROR = 'FailedOperation.GatewayRemoteCallError'
 
@@ -98,6 +125,12 @@ FAILEDOPERATION_GROUPEXISTS = 'FailedOperation.GroupExists'
 # 部署组查询失败。
 FAILEDOPERATION_GROUPQUERYFAILD = 'FailedOperation.GroupQueryFaild'
 
+# 镜像仓库已关联至部署组，请移除后重试
+FAILEDOPERATION_IMAGEVALIDATEISUSED = 'FailedOperation.ImageValidateIsUsed'
+
+# 禁止直接删除应用镜像仓库, 需要先删除下面的镜像tag
+FAILEDOPERATION_IMAGEREPOREJECTDELERROR = 'FailedOperation.ImagerepoRejectDelError'
+
 # tcr仓库绑定失败。
 FAILEDOPERATION_IMAGEREPOTCRBINDERROR = 'FailedOperation.ImagerepoTcrBindError'
 
@@ -170,6 +203,12 @@ FAILEDOPERATION_SERVICEINSERTFAILED = 'FailedOperation.ServiceInsertFailed'
 # 服务查询失败。
 FAILEDOPERATION_SERVICEQUERYFAILED = 'FailedOperation.ServiceQueryFailed'
 
+# 可观测性支持依赖TAPM业务系统绑定
+FAILEDOPERATION_TAPMBINDREQUIRED = 'FailedOperation.TapmBindRequired'
+
+# 请使用TAPM提供的Otel探针
+FAILEDOPERATION_TAPMEXPIREDOTEL = 'FailedOperation.TapmExpiredOtel'
+
 # 任务创建异常。
 FAILEDOPERATION_TASKCREATEERROR = 'FailedOperation.TaskCreateError'
 
@@ -203,6 +242,9 @@ FAILEDOPERATION_TKECLUSTERDELETEFAILED = 'FailedOperation.TkeClusterDeleteFailed
 # TKE 集群查询失败。
 FAILEDOPERATION_TKECLUSTERQUERYFAILED = 'FailedOperation.TkeClusterQueryFailed'
 
+# TOKEN查询失败。
+FAILEDOPERATION_TOKENQUERYFAILED = 'FailedOperation.TokenQueryFailed'
+
 # TSF应用性能管理任务数据库查询失败。
 FAILEDOPERATION_TSFAPMAGENTTASKQUERYERROR = 'FailedOperation.TsfApmAgentTaskQueryError'
 
@@ -236,6 +278,9 @@ FAILEDOPERATION_TSFAPMCALLTSFMSFAILED = 'FailedOperation.TsfApmCallTsfMsFailed'
 # TSF应用性能管理CTSDB客户端调用失败。
 FAILEDOPERATION_TSFAPMCTSDBCLIENTREQUESTERROR = 'FailedOperation.TsfApmCtsdbClientRequestError'
 
+# TSF应用性能管理ES客户端调用失败。
+FAILEDOPERATION_TSFAPMESCLIENTREQUESTERROR = 'FailedOperation.TsfApmEsClientRequestError'
+
 # TSF应用性能管理内部异常, 请稍后重试。
 FAILEDOPERATION_TSFAPMINTERNALERROR = 'FailedOperation.TsfApmInternalError'
 
@@ -263,6 +308,9 @@ FAILEDOPERATION_TSFCMONITORCTSDBCLIENTREQUESTFAIL = 'FailedOperation.TsfCmonitor
 # TSF监控统计等待超时, 请稍后重试。
 FAILEDOPERATION_TSFMONITORWAITEDTIMEOUT = 'FailedOperation.TsfMonitorWaitedTimeout'
 
+# TSF服务管理通用异常。
+FAILEDOPERATION_TSFMSERROR = 'FailedOperation.TsfMsError'
+
 # 调用ms server失败。
 FAILEDOPERATION_TSFMSSERVERERROR = 'FailedOperation.TsfMsServerError'
 
@@ -293,6 +341,9 @@ INTERNALERROR_CAMROLEREQUESTERROR = 'InternalError.CamRoleRequestError'
 # 配置发布失败：无法连接配置中心服务器。
 INTERNALERROR_CANNOTCONNCONSULSERVER = 'InternalError.CanNotConnConsulServer'
 
+# 调用CDI状态接口返回数据异常
+INTERNALERROR_CDISTATUSDATAINVALID = 'InternalError.CdiStatusDataInvalid'
+
 # TSF云API请求调用失败。
 INTERNALERROR_CLOUDAPIPROXYERROR = 'InternalError.CloudApiProxyError'
 
@@ -407,6 +458,9 @@ INTERNALERROR_TSFMONITORDATEPARSEFAILED = 'InternalError.TsfMonitorDateParseFail
 # TSF监控统计内部异常, 请稍后重试。
 INTERNALERROR_TSFMONITORINTERNALERROR = 'InternalError.TsfMonitorInternalError'
 
+# TSF服务管理通用异常。
+INTERNALERROR_TSFMSERROR = 'InternalError.TsfMsError'
+
 # [%s]模块未处理异常。。
 INTERNALERROR_UNHANDLEDEXCEPTION = 'InternalError.UnhandledException'
 
@@ -542,7 +596,7 @@ INVALIDPARAMETER_UPPERDELETELIMIT = 'InvalidParameter.UpperDeleteLimit'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# 应用描述不能大于200组字符。
+# 应用描述不能大于200个字符。
 INVALIDPARAMETERVALUE_APPLICATIONDESCLENGTH = 'InvalidParameterValue.ApplicationDescLength'
 
 # 无效的微服务类型。
@@ -563,6 +617,9 @@ INVALIDPARAMETERVALUE_APPLICATIONNAMEREGXINVALID = 'InvalidParameterValue.Applic
 # 无法获取应用。
 INVALIDPARAMETERVALUE_APPLICATIONNOTEXISTS = 'InvalidParameterValue.ApplicationNotExists'
 
+# 无效的应用排序类型。
+INVALIDPARAMETERVALUE_APPLICATIONORDERTYPEINVALID = 'InvalidParameterValue.ApplicationOrderTypeInvalid'
+
 # 无效的应用分页参数。
 INVALIDPARAMETERVALUE_APPLICATIONPAGELIMITINVALID = 'InvalidParameterValue.ApplicationPageLimitInvalid'
 
@@ -644,6 +701,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPAPPLICATIONIDNULL = 'InvalidParameterValue.C
 # 集群 CPU 资源不足。
 INVALIDPARAMETERVALUE_CONTAINERGROUPCPULIMITOVER = 'InvalidParameterValue.ContainergroupCpulimitOver'
 
+# 容器 Env 的 Value 和 ValueFrom 至少要有一个。
+INVALIDPARAMETERVALUE_CONTAINERGROUPENVVALUENOTSET = 'InvalidParameterValue.ContainergroupEnvValueNotSet'
+
 # 部署组ID不能为空。
 INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPIDNULL = 'InvalidParameterValue.ContainergroupGroupidNull'
 
@@ -677,6 +737,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPNODEPORTINVALID = 'InvalidParameterValue.Con
 # 服务端口值非法。
 INVALIDPARAMETERVALUE_CONTAINERGROUPPORTINVALID = 'InvalidParameterValue.ContainergroupPortInvalid'
 
+# 服务端口不能为空。
+INVALIDPARAMETERVALUE_CONTAINERGROUPPORTNULL = 'InvalidParameterValue.ContainergroupPortNull'
+
 # 服务端口不允许重复映射。
 INVALIDPARAMETERVALUE_CONTAINERGROUPPORTSREPEAT = 'InvalidParameterValue.ContainergroupPortsRepeat'
 
@@ -728,9 +791,15 @@ INVALIDPARAMETERVALUE_CVMCAEMASTERTASKNOTEXIST = 'InvalidParameterValue.CvmCaeMa
 # 部署组不存在。
 INVALIDPARAMETERVALUE_DEPLOYGROUPNOTEXISTS = 'InvalidParameterValue.DeployGroupNotExists'
 
+# 重复数据集名。
+INVALIDPARAMETERVALUE_DUPLICATEPROGRAMNAME = 'InvalidParameterValue.DuplicateProgramName'
+
 # 文件配置项已经发布。
 INVALIDPARAMETERVALUE_FILECONFIGALREADYRELEASED = 'InvalidParameterValue.FileConfigAlreadyReleased'
 
+# 文件配置项编码方式不支持。
+INVALIDPARAMETERVALUE_FILECONFIGCODEUNSUPPORTED = 'InvalidParameterValue.FileConfigCodeUnsupported'
+
 # 文件配置项已存在。
 INVALIDPARAMETERVALUE_FILECONFIGEXISTS = 'InvalidParameterValue.FileConfigExists'
 
@@ -746,6 +815,9 @@ INVALIDPARAMETERVALUE_FILECONFIGFILENAMEINVALID = 'InvalidParameterValue.FileCon
 # 文件配置项文件路径不合规。
 INVALIDPARAMETERVALUE_FILECONFIGFILEPATHINVALID = 'InvalidParameterValue.FileConfigFilePathInvalid'
 
+# 文件配置项固定字段不可变更。
+INVALIDPARAMETERVALUE_FILECONFIGFIXEDFIELDUNCHANGEABLE = 'InvalidParameterValue.FileConfigFixedFieldUnchangeable'
+
 # 文件配置项名称不合规。
 INVALIDPARAMETERVALUE_FILECONFIGNAMEINVALID = 'InvalidParameterValue.FileConfigNameInvalid'
 
@@ -761,6 +833,9 @@ INVALIDPARAMETERVALUE_FILECONFIGRELEASENOTEXISTS = 'InvalidParameterValue.FileCo
 # 文件配置项版本描述不合规。
 INVALIDPARAMETERVALUE_FILECONFIGVERSIONDESCINVALID = 'InvalidParameterValue.FileConfigVersionDescInvalid'
 
+# 文件配置项版本不合规。
+INVALIDPARAMETERVALUE_FILECONFIGVERSIONINVALID = 'InvalidParameterValue.FileConfigVersionInvalid'
+
 # 请求参数异常:%s。
 INVALIDPARAMETERVALUE_GATEWAYPARAMETERERROR = 'InvalidParameterValue.GatewayParameterError'
 
@@ -824,6 +899,9 @@ INVALIDPARAMETERVALUE_INVALIDPARAMETER = 'InvalidParameterValue.InvalidParameter
 # 参数格式异常。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERFORMAT = 'InvalidParameterValue.InvalidParameterFormat'
 
+# 数据集名非法。
+INVALIDPARAMETERVALUE_INVALIDPROGRAMNAME = 'InvalidParameterValue.InvalidProgramName'
+
 # 已经绑定灰度规则，无法删除。
 INVALIDPARAMETERVALUE_LANEINFOALREADYUSED = 'InvalidParameterValue.LaneInfoAlreadyUsed'
 
@@ -848,6 +926,9 @@ INVALIDPARAMETERVALUE_LANEINFONOTEXISTENTRANCE = 'InvalidParameterValue.LaneInfo
 # 泳道备注不能超过200个字符。
 INVALIDPARAMETERVALUE_LANEINFOREMARKTOOLONG = 'InvalidParameterValue.LaneInfoRemarkTooLong'
 
+# 全链路灰度规则ID错误
+INVALIDPARAMETERVALUE_LANERULEIDINVALID = 'InvalidParameterValue.LaneRuleIdInvalid'
+
 # 全链路灰度规则中的泳道不存在。
 INVALIDPARAMETERVALUE_LANERULEINFONOTEXIST = 'InvalidParameterValue.LaneRuleInfoNotExist'
 
@@ -878,6 +959,15 @@ INVALIDPARAMETERVALUE_LANERULETAGNAMETOOLONG = 'InvalidParameterValue.LaneRuleTa
 # 全链路灰度规则必须设置至少一个标签。
 INVALIDPARAMETERVALUE_LANERULETAGNOTEMPTY = 'InvalidParameterValue.LaneRuleTagNotEmpty'
 
+# 全链路灰度规则逻辑关系错误
+INVALIDPARAMETERVALUE_LANERULETAGOPERATORINVALID = 'InvalidParameterValue.LaneRuleTagOperatorInvalid'
+
+# 全链路灰度规则逻辑关系不能为空
+INVALIDPARAMETERVALUE_LANERULETAGOPERATORNOTEMPTY = 'InvalidParameterValue.LaneRuleTagOperatorNotEmpty'
+
+# 全链路灰度规则标签值不能为空
+INVALIDPARAMETERVALUE_LANERULETAGVALUENOTEMPTY = 'InvalidParameterValue.LaneRuleTagValueNotEmpty'
+
 # 全链路灰度规则标签值不能超过128个字符。
 INVALIDPARAMETERVALUE_LANERULETAGVALUETOOLONG = 'InvalidParameterValue.LaneRuleTagValueTooLong'
 
@@ -887,7 +977,7 @@ INVALIDPARAMETERVALUE_LANERULETAGVALUETOTALTOOLONG = 'InvalidParameterValue.Lane
 # 集群已关联该命名空间。
 INVALIDPARAMETERVALUE_NAMESPACEALREADYBINDCLUSTER = 'InvalidParameterValue.NamespaceAlreadyBindCluster'
 
-# 命名空间描格式不正确。
+# 命名空间描述格式不正确。
 INVALIDPARAMETERVALUE_NAMESPACEDESCINVALID = 'InvalidParameterValue.NamespaceDescInvalid'
 
 # 命名空间名称已存在，请更换其他名称。
@@ -899,6 +989,9 @@ INVALIDPARAMETERVALUE_NAMESPACENAMEINVALID = 'InvalidParameterValue.NamespaceNam
 # 无法获取命名空间。
 INVALIDPARAMETERVALUE_NAMESPACENOTEXISTS = 'InvalidParameterValue.NamespaceNotExists'
 
+# 数据集项不存在。
+INVALIDPARAMETERVALUE_PROGRAMITEMNOTEXISTS = 'InvalidParameterValue.ProgramItemNotExists'
+
 # 配置项已经发布，不允许删除。
 INVALIDPARAMETERVALUE_RELEASEDCONFIGCANNOTBEDELETED = 'InvalidParameterValue.ReleasedConfigCanNotBeDeleted'
 
@@ -923,6 +1016,9 @@ INVALIDPARAMETERVALUE_SERVICENOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValu
 # 无效请求参数。
 INVALIDPARAMETERVALUE_TASKPARAMETERINVALID = 'InvalidParameterValue.TaskParameterInvalid'
 
+# TSF应用性能管理业务日志搜索解析时间格式错误。
+INVALIDPARAMETERVALUE_TSFAPMBUSILOGSEARCHPARSERSPDATEFORMATERROR = 'InvalidParameterValue.TsfApmBusiLogSearchParseRspDateFormatError'
+
 # 仅有停止状态下的部署组才可以不启动。
 INVALIDPARAMETERVALUE_WRONGDONTSTARTVALUE = 'InvalidParameterValue.WrongDontStartValue'
 
@@ -1007,6 +1103,9 @@ MISSINGPARAMETER_INSTANCEIMPORTMODENULL = 'MissingParameter.InstanceImportModeNu
 # 命名空间ID不能为空。
 MISSINGPARAMETER_NAMESPACEIDREQUIRED = 'MissingParameter.NamespaceIdRequired'
 
+# 命名空间名称未填写。
+MISSINGPARAMETER_NAMESPACENAMEREQUIRED = 'MissingParameter.NamespaceNameRequired'
+
 # %s缺失。
 MISSINGPARAMETER_REQUIREDPARAMETERMISSING = 'MissingParameter.RequiredParameterMissing'
 
