@@ -38,13 +38,22 @@ class CheckAnimateImageJobRequest(AbstractModel):
 图片大小：不超过10M；
 图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
         :type ImageBase64: str
-        :param _EnableBodyJoins: 是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
+        :param _EnableBodyJoins: 是否对输入图采用加强检测方案。
+
+默认不加强检测（false），仅对输入图做必要的基础检测。
+
+开启加强检测（true）有助于提升效果稳定性，将根据选择的动作模板提取建议的人体关键点，并判断输入图中是否包含这些人体关键点。加强检测仅对人像输入图生效，对非人输入图不生效。
         :type EnableBodyJoins: bool
+        :param _EnableFace: 是否开启人脸检测。
+
+默认开启人脸检测（true），拦截主体为人像但无人脸、人脸不完整或被遮挡的输入图。可选关闭人脸检测（false）。
+        :type EnableFace: bool
         """
         self._TemplateId = None
         self._ImageUrl = None
         self._ImageBase64 = None
         self._EnableBodyJoins = None
+        self._EnableFace = None
 
     @property
     def TemplateId(self):
@@ -88,7 +97,11 @@ class CheckAnimateImageJobRequest(AbstractModel):
 
     @property
     def EnableBodyJoins(self):
-        """是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
+        """是否对输入图采用加强检测方案。
+
+默认不加强检测（false），仅对输入图做必要的基础检测。
+
+开启加强检测（true）有助于提升效果稳定性，将根据选择的动作模板提取建议的人体关键点，并判断输入图中是否包含这些人体关键点。加强检测仅对人像输入图生效，对非人输入图不生效。
         :rtype: bool
         """
         return self._EnableBodyJoins
@@ -97,12 +110,26 @@ class CheckAnimateImageJobRequest(AbstractModel):
     def EnableBodyJoins(self, EnableBodyJoins):
         self._EnableBodyJoins = EnableBodyJoins
 
+    @property
+    def EnableFace(self):
+        """是否开启人脸检测。
+
+默认开启人脸检测（true），拦截主体为人像但无人脸、人脸不完整或被遮挡的输入图。可选关闭人脸检测（false）。
+        :rtype: bool
+        """
+        return self._EnableFace
+
+    @EnableFace.setter
+    def EnableFace(self, EnableFace):
+        self._EnableFace = EnableFace
+
 
     def _deserialize(self, params):
         self._TemplateId = params.get("TemplateId")
         self._ImageUrl = params.get("ImageUrl")
         self._ImageBase64 = params.get("ImageBase64")
         self._EnableBodyJoins = params.get("EnableBodyJoins")
+        self._EnableFace = params.get("EnableFace")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -457,6 +484,130 @@ class DescribePortraitSingJobResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class DescribeTemplateToVideoJobRequest(AbstractModel):
+    """DescribeTemplateToVideoJob请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _JobId: 任务ID。
+        :type JobId: str
+        """
+        self._JobId = None
+
+    @property
+    def JobId(self):
+        """任务ID。
+        :rtype: str
+        """
+        return self._JobId
+
+    @JobId.setter
+    def JobId(self, JobId):
+        self._JobId = JobId
+
+
+    def _deserialize(self, params):
+        self._JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeTemplateToVideoJobResponse(AbstractModel):
+    """DescribeTemplateToVideoJob返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Status: 任务状态。WAIT：等待中，RUN：执行中，FAIL：任务失败，DONE：任务成功
+        :type Status: str
+        :param _ErrorCode: 任务执行错误码。当任务状态不为 FAIL 时，该值为""。
+        :type ErrorCode: str
+        :param _ErrorMessage: 任务执行错误信息。当任务状态不为 FAIL 时，该值为""。
+        :type ErrorMessage: str
+        :param _ResultVideoUrl: 结果视频 URL。有效期 24 小时。
+        :type ResultVideoUrl: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._Status = None
+        self._ErrorCode = None
+        self._ErrorMessage = None
+        self._ResultVideoUrl = None
+        self._RequestId = None
+
+    @property
+    def Status(self):
+        """任务状态。WAIT：等待中，RUN：执行中，FAIL：任务失败，DONE：任务成功
+        :rtype: str
+        """
+        return self._Status
+
+    @Status.setter
+    def Status(self, Status):
+        self._Status = Status
+
+    @property
+    def ErrorCode(self):
+        """任务执行错误码。当任务状态不为 FAIL 时，该值为""。
+        :rtype: str
+        """
+        return self._ErrorCode
+
+    @ErrorCode.setter
+    def ErrorCode(self, ErrorCode):
+        self._ErrorCode = ErrorCode
+
+    @property
+    def ErrorMessage(self):
+        """任务执行错误信息。当任务状态不为 FAIL 时，该值为""。
+        :rtype: str
+        """
+        return self._ErrorMessage
+
+    @ErrorMessage.setter
+    def ErrorMessage(self, ErrorMessage):
+        self._ErrorMessage = ErrorMessage
+
+    @property
+    def ResultVideoUrl(self):
+        """结果视频 URL。有效期 24 小时。
+        :rtype: str
+        """
+        return self._ResultVideoUrl
+
+    @ResultVideoUrl.setter
+    def ResultVideoUrl(self, ResultVideoUrl):
+        self._ResultVideoUrl = ResultVideoUrl
+
+    @property
+    def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._Status = params.get("Status")
+        self._ErrorCode = params.get("ErrorCode")
+        self._ErrorMessage = params.get("ErrorMessage")
+        self._ResultVideoUrl = params.get("ResultVideoUrl")
+        self._RequestId = params.get("RequestId")
+
+
 class DescribeVideoStylizationJobRequest(AbstractModel):
     """DescribeVideoStylizationJob请求参数结构体
 
@@ -601,6 +752,57 @@ JobSuccess: "处理完成"。
         self._RequestId = params.get("RequestId")
 
 
+class Image(AbstractModel):
+    """图片
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Base64: 图片Base64
+        :type Base64: str
+        :param _Url: 图片Url
+        :type Url: str
+        """
+        self._Base64 = None
+        self._Url = None
+
+    @property
+    def Base64(self):
+        """图片Base64
+        :rtype: str
+        """
+        return self._Base64
+
+    @Base64.setter
+    def Base64(self, Base64):
+        self._Base64 = Base64
+
+    @property
+    def Url(self):
+        """图片Url
+        :rtype: str
+        """
+        return self._Url
+
+    @Url.setter
+    def Url(self, Url):
+        self._Url = Url
+
+
+    def _deserialize(self, params):
+        self._Base64 = params.get("Base64")
+        self._Url = params.get("Url")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class LogoParam(AbstractModel):
     """logo参数
 
@@ -773,7 +975,11 @@ class SubmitImageAnimateJobRequest(AbstractModel):
         :type TemplateId: str
         :param _EnableAudio: 结果视频是否保留模板音频。默认为true
         :type EnableAudio: bool
-        :param _EnableBodyJoins: 是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
+        :param _EnableBodyJoins: 是否对输入图采用加强检测方案。
+
+默认不加强检测（false），仅对输入图做必要的基础检测。
+
+开启加强检测（true）有助于提升效果稳定性，将根据选择的动作模板提取建议的人体关键点，并判断输入图中是否包含这些人体关键点。加强检测仅对人像输入图生效，对非人输入图不生效。
         :type EnableBodyJoins: bool
         :param _EnableSegment: 是否对结果视频背景进行分割，默认值为false。
 true：分割结果视频，结果视频（ResultVideoUrl）将为去除背景的绿幕视频，并返回掩码视频（MaskVideoUrl）；
@@ -788,6 +994,10 @@ false：不分割结果视频，结果视频（ResultVideoUrl）为带背景的
         :param _LogoParam: 标识内容设置。
 默认在生成视频的右下角添加“视频由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
         :type LogoParam: :class:`tencentcloud.vclm.v20240523.models.LogoParam`
+        :param _EnableFace: 是否开启人脸检测。
+
+默认开启人脸检测（true），拦截主体为人像但无人脸、人脸不完整或被遮挡的输入图。可选关闭人脸检测（false）。
+        :type EnableFace: bool
         """
         self._ImageUrl = None
         self._ImageBase64 = None
@@ -797,6 +1007,7 @@ false：不分割结果视频，结果视频（ResultVideoUrl）为带背景的
         self._EnableSegment = None
         self._LogoAdd = None
         self._LogoParam = None
+        self._EnableFace = None
 
     @property
     def ImageUrl(self):
@@ -852,7 +1063,11 @@ false：不分割结果视频，结果视频（ResultVideoUrl）为带背景的
 
     @property
     def EnableBodyJoins(self):
-        """是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
+        """是否对输入图采用加强检测方案。
+
+默认不加强检测（false），仅对输入图做必要的基础检测。
+
+开启加强检测（true）有助于提升效果稳定性，将根据选择的动作模板提取建议的人体关键点，并判断输入图中是否包含这些人体关键点。加强检测仅对人像输入图生效，对非人输入图不生效。
         :rtype: bool
         """
         return self._EnableBodyJoins
@@ -901,6 +1116,19 @@ false：不分割结果视频，结果视频（ResultVideoUrl）为带背景的
     def LogoParam(self, LogoParam):
         self._LogoParam = LogoParam
 
+    @property
+    def EnableFace(self):
+        """是否开启人脸检测。
+
+默认开启人脸检测（true），拦截主体为人像但无人脸、人脸不完整或被遮挡的输入图。可选关闭人脸检测（false）。
+        :rtype: bool
+        """
+        return self._EnableFace
+
+    @EnableFace.setter
+    def EnableFace(self, EnableFace):
+        self._EnableFace = EnableFace
+
 
     def _deserialize(self, params):
         self._ImageUrl = params.get("ImageUrl")
@@ -913,6 +1141,7 @@ false：不分割结果视频，结果视频（ResultVideoUrl）为带背景的
         if params.get("LogoParam") is not None:
             self._LogoParam = LogoParam()
             self._LogoParam._deserialize(params.get("LogoParam"))
+        self._EnableFace = params.get("EnableFace")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -997,7 +1226,7 @@ Pet：宠物模式，支持宠物等非人像图片，固定生成512:512分辨
 
 宠物模式下，如果不传该参数，默认将脸部唱演视频回贴原图，生成视频分辨率与原图一致。如不需要脸部回贴，仅保留脸部唱演视频，可传入512:512。
         :type Resolution: str
-        :param _LogoAdd: 为生成视频添加标识的开关，默认为0。 
+        :param _LogoAdd: 为生成视频添加标识的开关，默认为1。 
 1：添加标识；
  0：不添加标识；
 其他数值：默认按1处理。 
@@ -1085,7 +1314,7 @@ Pet：宠物模式，支持宠物等非人像图片，固定生成512:512分辨
 
     @property
     def LogoAdd(self):
-        """为生成视频添加标识的开关，默认为0。 
+        """为生成视频添加标识的开关，默认为1。 
 1：添加标识；
  0：不添加标识；
 其他数值：默认按1处理。 
@@ -1173,6 +1402,181 @@ class SubmitPortraitSingJobResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class SubmitTemplateToVideoJobRequest(AbstractModel):
+    """SubmitTemplateToVideoJob请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Template: 特效模板名称。
+枚举值：
+hug ：拥抱
+kiss ：亲吻
+heart ： 比心
+fuzzy ： 毛茸茸
+befigure：变手办风
+longhair：金色长发
+morphlab：膨胀
+bloom：万物生花
+pinch：捏捏
+balloonfly：飞走了
+dragme：被拽走了
+
+        :type Template: str
+        :param _Images: 参考图像，最多输入2张图。
+- 支持传入图片Base64编码或图片URL（确保可访问）
+- 图片格式：支持png、jpg、jpeg、webp、bmp、tiff
+- 图片文件：大小不能超过10MB（base64后），图片分辨率不小于300\*300px，不大于4096\*4096，图片宽高比应在1:4 ~ 4:1之间
+
+        :type Images: list of Image
+        :param _LogoAdd: 为生成视频添加标识的开关，默认为1。
+1：添加标识。
+0：不添加标识。
+其他数值：默认按1处理。
+建议您使用显著标识来提示，该视频是 AI 生成的视频。
+        :type LogoAdd: int
+        :param _LogoParam: 标识内容设置。
+默认在生成视频的右下角添加“视频由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :type LogoParam: :class:`tencentcloud.vclm.v20240523.models.LogoParam`
+        """
+        self._Template = None
+        self._Images = None
+        self._LogoAdd = None
+        self._LogoParam = None
+
+    @property
+    def Template(self):
+        """特效模板名称。
+枚举值：
+hug ：拥抱
+kiss ：亲吻
+heart ： 比心
+fuzzy ： 毛茸茸
+befigure：变手办风
+longhair：金色长发
+morphlab：膨胀
+bloom：万物生花
+pinch：捏捏
+balloonfly：飞走了
+dragme：被拽走了
+
+        :rtype: str
+        """
+        return self._Template
+
+    @Template.setter
+    def Template(self, Template):
+        self._Template = Template
+
+    @property
+    def Images(self):
+        """参考图像，最多输入2张图。
+- 支持传入图片Base64编码或图片URL（确保可访问）
+- 图片格式：支持png、jpg、jpeg、webp、bmp、tiff
+- 图片文件：大小不能超过10MB（base64后），图片分辨率不小于300\*300px，不大于4096\*4096，图片宽高比应在1:4 ~ 4:1之间
+
+        :rtype: list of Image
+        """
+        return self._Images
+
+    @Images.setter
+    def Images(self, Images):
+        self._Images = Images
+
+    @property
+    def LogoAdd(self):
+        """为生成视频添加标识的开关，默认为1。
+1：添加标识。
+0：不添加标识。
+其他数值：默认按1处理。
+建议您使用显著标识来提示，该视频是 AI 生成的视频。
+        :rtype: int
+        """
+        return self._LogoAdd
+
+    @LogoAdd.setter
+    def LogoAdd(self, LogoAdd):
+        self._LogoAdd = LogoAdd
+
+    @property
+    def LogoParam(self):
+        """标识内容设置。
+默认在生成视频的右下角添加“视频由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :rtype: :class:`tencentcloud.vclm.v20240523.models.LogoParam`
+        """
+        return self._LogoParam
+
+    @LogoParam.setter
+    def LogoParam(self, LogoParam):
+        self._LogoParam = LogoParam
+
+
+    def _deserialize(self, params):
+        self._Template = params.get("Template")
+        if params.get("Images") is not None:
+            self._Images = []
+            for item in params.get("Images"):
+                obj = Image()
+                obj._deserialize(item)
+                self._Images.append(obj)
+        self._LogoAdd = params.get("LogoAdd")
+        if params.get("LogoParam") is not None:
+            self._LogoParam = LogoParam()
+            self._LogoParam._deserialize(params.get("LogoParam"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SubmitTemplateToVideoJobResponse(AbstractModel):
+    """SubmitTemplateToVideoJob返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _JobId: 任务ID。
+        :type JobId: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._JobId = None
+        self._RequestId = None
+
+    @property
+    def JobId(self):
+        """任务ID。
+        :rtype: str
+        """
+        return self._JobId
+
+    @JobId.setter
+    def JobId(self, JobId):
+        self._JobId = JobId
+
+    @property
+    def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._JobId = params.get("JobId")
+        self._RequestId = params.get("RequestId")
+
+
 class SubmitVideoStylizationJobRequest(AbstractModel):
     """SubmitVideoStylizationJob请求参数结构体
 
